#!/usr/bin/env python3
"""
Power Monitoring system web interface
Provides temperature and recent log file entries
"""
from flask import Flask, render_template
from waitress import serve
from datetime import datetime
import os
import psutil
import ds18b20


app = Flask(__name__)


@app.route('/')
def load_webpage():
    # http://mattrichardson.com/Raspberry-Pi-Flask/index.html was very helpful

    # Get current Date/Time
    datetimenow = get_formatted_datetime()

    # Get status of powmon.service
    if os.system('systemctl -q is-active powmon.service') == 0:
        scriptstatus = '<span style="color:green">Active</span>'
    else:
        scriptstatus = '<font color="red">Inactive</font>'

    # Get memory usage
    memusage = psutil.virtual_memory()[2]

    # Get temp
    temps = ds18b20.read_temp()
    if temps is not None:
        temperature = '{:.1f}'.format(temps[1])
    else:
        temperature = '???'

    # Get Log file entries in unordered list
    # Based on http://stackoverflow.com/a/10716137
    logfileraw = os.popen('tail -n50 powmon.log | tac').read()
    lines = logfileraw.splitlines()
    logfile = '<ul>\n<li>' + '</li>\n<li>'.join(lines) + '</li></ul>'

    templateData = {
        'datetimenow': datetimenow,
        'scriptstatus': scriptstatus,
        'memusage': memusage,
        'temperature': temperature,
        'logfile': logfile
        }

    return render_template('index.html', **templateData)


def get_formatted_datetime():
    datetimenow = datetime.now()
    return datetimenow.strftime('%m-%d-%Y %-I:%M%p')


if __name__ == '__main__':
    # Debug using Werkzeug dev server
    # app.run(host='0.0.0.0', debug=True)

    # Deploy with Waitress WSGI server
    serve(app)
